==> zio-aws-ec2_2.13-5.17.104.3-sources.jar: zio/aws/ec2/model/AcceptVpcPeeringConnectionResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AcceptVpcPeeringConnectionResponse(
    vpcPeeringConnection: Option[zio.aws.ec2.model.VpcPeeringConnection] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse = {
    import AcceptVpcPeeringConnectionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
      .builder()
      .optionallyWith(vpcPeeringConnection.map(value => value.buildAwsValue()))(
        _.vpcPeeringConnection
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.ReadOnly =
    zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.wrap(buildAwsValue())
}
object AcceptVpcPeeringConnectionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse =
      zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse(
        vpcPeeringConnection.map(value => value.asEditable)
      )
    def vpcPeeringConnection
        : Option[zio.aws.ec2.model.VpcPeeringConnection.ReadOnly]
    def getVpcPeeringConnection
        : ZIO[Any, AwsError, zio.aws.ec2.model.VpcPeeringConnection.ReadOnly] =
      AwsError.unwrapOptionField("vpcPeeringConnection", vpcPeeringConnection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
  ) extends zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.ReadOnly {
    override val vpcPeeringConnection
        : Option[zio.aws.ec2.model.VpcPeeringConnection.ReadOnly] = scala
      .Option(impl.vpcPeeringConnection())
      .map(value => zio.aws.ec2.model.VpcPeeringConnection.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
  ): zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.181.1-sources.jar: zio/aws/ec2/model/AcceptVpcPeeringConnectionResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AcceptVpcPeeringConnectionResponse(
    vpcPeeringConnection: Optional[zio.aws.ec2.model.VpcPeeringConnection] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse = {
    import AcceptVpcPeeringConnectionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
      .builder()
      .optionallyWith(vpcPeeringConnection.map(value => value.buildAwsValue()))(
        _.vpcPeeringConnection
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.ReadOnly =
    zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.wrap(buildAwsValue())
}
object AcceptVpcPeeringConnectionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse =
      zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse(
        vpcPeeringConnection.map(value => value.asEditable)
      )
    def vpcPeeringConnection
        : Optional[zio.aws.ec2.model.VpcPeeringConnection.ReadOnly]
    def getVpcPeeringConnection
        : ZIO[Any, AwsError, zio.aws.ec2.model.VpcPeeringConnection.ReadOnly] =
      AwsError.unwrapOptionField("vpcPeeringConnection", vpcPeeringConnection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
  ) extends zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.ReadOnly {
    override val vpcPeeringConnection
        : Optional[zio.aws.ec2.model.VpcPeeringConnection.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vpcPeeringConnection())
        .map(value => zio.aws.ec2.model.VpcPeeringConnection.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AcceptVpcPeeringConnectionResponse
  ): zio.aws.ec2.model.AcceptVpcPeeringConnectionResponse.ReadOnly =
    new Wrapper(impl)
}
